@@ -65,11 +65,11 @@ void prefs_dialog_response(GtkDialog *prefs_dialog,
         case GTK_RESPONSE_HELP:
                 g_debug("loading help in prefs");
                 current_page = gtk_notebook_get_current_page(sensors_applet->prefs_dialog->notebook);
-		uri = g_strdup_printf("ghelp:sensors-applet?%s",
+		uri = g_strdup_printf("http://wiki.mate-desktop.org/docs:mate-sensors-applet#%s",
 				      ((current_page == 0) ?
-				       "sensors-applet-general-options" :
+				       "general_options" :
 				       ((current_page == 1) ?
-					"sensors-applet-sensors" :
+					"sensors" :
 					NULL)));
                 gtk_show_uri(NULL, uri, gtk_get_current_event_time(), &error);
 		g_free(uri);
