@@ -80,7 +80,7 @@ static void help_cb(MateComponentUIComponent *uic,
 
         GError *error = NULL;
         
-        gtk_show_uri(NULL, "ghelp:sensors-applet",
+        gtk_show_uri(NULL, "http://wiki.mate-desktop.org/docs:mate-sensors-applet",
 		     gtk_get_current_event_time(),
 		     &error);
         
